package com.qmth.teachcloud.obe.service;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.IService;
import com.qmth.teachcloud.obe.been.obe.CourseRequirementMatrixDto;
import com.qmth.teachcloud.obe.been.report.ObeCourseRequirementDto;
import com.qmth.teachcloud.obe.been.report.ObeSubRequirementsDto;
import com.qmth.teachcloud.obe.been.result.ObeCourseRequirementListResult;
import com.qmth.teachcloud.obe.entity.ObeCourseRequirementReport;

import java.util.List;
import java.util.Map;

/**
 * <p>
 * 课程毕业要求报表 服务类
 * </p>
 *
 * @author wangliang
 * @since 2024-06-13
 */
public interface ObeCourseRequirementReportService extends IService<ObeCourseRequirementReport> {

    /**
     * 雷达报表计算方法
     *
     * @param cultureProgramId 培养方案id
     * @return 结果
     */
    public ObeCourseRequirementDto calculate(Long cultureProgramId);

    /**
     * 雷达详情报表计算方法
     *
     * @param cultureProgramId 培养方案id
     * @return 结果
     */
    public List<ObeCourseRequirementDto> calculateDetail(Long cultureProgramId);

    /**
     * 换算课程毕业达成度报表详情
     *
     * @param courseRequirementMatrixDtoList courseRequirementMatrixDtoList
     * @param obeCourseOutlineId             课程大纲id
     * @param examId                         考试id
     * @return 结果
     */
    public Map<String, Object> matrixCourseReportInfo(List<CourseRequirementMatrixDto> courseRequirementMatrixDtoList,
            Long obeCourseOutlineId, Long examId, List<ObeCourseRequirementDto> obeCourseRequirementDtoList, Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 换算课程毕业达成度报表
     *
     * @param obeCourseRequirementDtoList obeCourseRequirementDtoList
     * @param obeSubRequirementsDtoMap    obeSubRequirementsDtoMap
     * @return 结果
     */
    public ObeCourseRequirementDto matrixCourseReport(List<ObeCourseRequirementDto> obeCourseRequirementDtoList, Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 换算课程毕业达成度报表共用
     *
     * @param obeCourseRequirementDtoList obeCourseRequirementDtoList
     * @param obeSubRequirementsDtoMap    obeSubRequirementsDtoMap
     * @return 结果
     */
    public List<ObeCourseRequirementDto> matrixCourseReportCommon(List<ObeCourseRequirementDto> obeCourseRequirementDtoList,
            Map<Long, List<ObeSubRequirementsDto>> obeSubRequirementsDtoMap);

    /**
     * 查找课程毕业达成度报表列表
     *
     * @param iPage              分页参数
     * @param professionalId     培养方案id
     * @param cultureProgramName 培养方案名称
     * @return 结果
     */
    public IPage<ObeCourseRequirementListResult> obeCourseRequirementReportList(IPage<Map> iPage, Long professionalId,
            String cultureProgramName);

    /**
     * 根据培养方案删除报表
     *
     * @param cultureProgramId 培养方案id
     * @return 结果
     */
    public boolean removeReport(Long cultureProgramId);

    /**
     * 根据培养方案查询报表
     *
     * @param cultureProgramId 培养方案id
     * @return 结果
     */
    ObeCourseRequirementReport findByCultureProgramId(Long cultureProgramId);
}